==> tinybig-0.1.0.post9.tar.gz: tinybig-0.1.0.post9/docs/tutorials/beginner/index.md <==
# Beginner's Tutorials


This page will be updated as new tutorials are posted, so please check back regularly.

## Tutorial Organization

|                     Tutorial ID                      |       Tutorial Title        |      Last Update      |                 Jupyter Notebook Code                  |
|:----------------------------------------------------:|:---------------------------:|:---------------------:|:------------------------------------------------------:|
|      [Tutorial 0](../../guides/quick_start.md)       |     Quickstart Tutorial     |     July 6, 20204     | [Jupyter Notes](../../notes/quickstart_tutorial.ipynb) |
|     [Tutorial 1](./module/expansion_function.md)     |  Data Expansion Functions   |     July 7, 2024      | [Jupyter Notes](../../notes/expansion_tutorial.ipynb)  |

[//]: # (| [Tutorial 2]&#40;./module/extended_nested_expansion.md&#41; | Extended and Nested Data Expansions |     TBD      | To Be Provided  |)

[//]: # (|  [Tutorial 3]&#40;./module/reconciliation_function.md&#41;  | Parameter Reconciliation Functions  |     TBD      | To Be Provided  |)

[//]: # (|    [Tutorial 4]&#40;./module/remainder_function.md&#41;     |         Remainder Functions         |     TBD      | To Be Provided  |)

[//]: # (| [Tutorial 5]&#40;./module/data_processing_function.md&#41;  |      Data Processing Functions      |     TBD      | To Be Provided  |)

[//]: # ()
[//]: # ()
[//]: # (## Tutorials on {{ our }} Model Architecture)

[//]: # ()
[//]: # (|             Tutorial ID             |              Tutorial Title              | Release Date |   Colab Link    |)

[//]: # (|:-----------------------------------:|:----------------------------------------:|:------------:|:---------------:|)

[//]: # (| [Tutorial 6]&#40;./model/rpn_model.md&#41;  |          RPN Model Architecture          |     TBD      | To Be Provided  |)

[//]: # (|  [Tutorial 7]&#40;./model/wide_rpn.md&#41;  |       RPN with Wide Architectures        |     TBD      | To Be Provided  |)

[//]: # (|  [Tutorial 8]&#40;./model/deep_rpn.md&#41;  |        RPN with Deep Architecture        |     TBD      | To Be Provided  |)

[//]: # (| [Tutorial 9]&#40;./model/rpn_config.md&#41; |         RPN Model Configurations         |     TBD      | To Be Provided  |)

[//]: # ()
[//]: # ()
[//]: # (## Tutorials on Datasets for {{ our }} Training)

[//]: # ()
[//]: # (|              Tutorial ID               |       Tutorial Title        | Release Date |   Colab Link    |)

[//]: # (|:--------------------------------------:|:---------------------------:|:------------:|:---------------:|)

[//]: # (| [Tutorial 10]&#40;./data/function_data.md&#41; | Continuous Function Dataset |     TBD      | To Be Provided  |)

[//]: # (|  [Tutorial 11]&#40;./data/image_data.md&#41;   |   Discrete Image Dataset    |     TBD      | To Be Provided  |)

[//]: # (|   [Tutorial 12]&#40;./data/text_data.md&#41;   |    Discrete Text Dataset    |     TBD      | To Be Provided  |)

[//]: # (| [Tutorial 13]&#40;./data/tabular_data.md&#41;  |   Classic Tabular Dataset   |     TBD      | To Be Provided  |)

[//]: # ()
[//]: # (## Tutorials on Deep Function Learning Tasks with {{ our }})

[//]: # ()
[//]: # (|                   Tutorial ID                   |           Tutorial Title           | Release Date |   Colab Link    |)

[//]: # (|:-----------------------------------------------:|:----------------------------------:|:------------:|:---------------:|)

[//]: # (| [Tutorial 14]&#40;./task/function_approximation.md&#41; | Continuous Function Approximation  |     TBD      | To Be Provided  |)

[//]: # (|  [Tutorial 15]&#40;./task/image_classification.md&#41;  |   Discrete Image Classification    |     TBD      | To Be Provided  |)

[//]: # (|  [Tutorial 16]&#40;./task/text_classification.md&#41;   |    Discrete Text Classification    |     TBD      | To Be Provided  |)

[//]: # (|  [Tutorial 17]&#40;./task/dependency_inference.md&#41;  | Probabilistic Dependency Inference |     TBD      | To Be Provided  |)

[//]: # ()

==> tinybig-0.1.1.tar.gz: tinybig-0.1.1/docs/tutorials/beginner/index.md <==
# Beginner's Tutorials


This page will be updated as new tutorials are posted, so please check back regularly.

## Tutorial Organization

{% set quickstart_tutorial_files %}<a href="https://github.com/jwzhanggy/tinyBIG/blob/main/docs/notes/quickstart_tutorial.ipynb"><img src="https://raw.githubusercontent.com/jwzhanggy/tinyBIG/main/docs/assets/img/ipynb_icon.png" alt="Jupyter Logo" style="height: 2em; vertical-align: middle; margin-right: 4px;"></a>  <a href="https://github.com/jwzhanggy/tinyBIG/blob/main/docs/notes/quickstart_tutorial.py"><img src="https://raw.githubusercontent.com/jwzhanggy/tinyBIG/main/docs/assets/img/python_icon.svg" alt="Python Logo" style="height: 2em; vertical-align: middle; margin-right: 10px;"></a>{% endset %}
{% set expansion_tutorial_files %}<a href="https://github.com/jwzhanggy/tinyBIG/blob/main/docs/notes/expansion_tutorial.ipynb"><img src="https://raw.githubusercontent.com/jwzhanggy/tinyBIG/main/docs/assets/img/ipynb_icon.png" alt="Jupyter Logo" style="height: 2em; vertical-align: middle; margin-right: 10px;"></a> <a href="https://github.com/jwzhanggy/tinyBIG/blob/main/docs/notes/configs/expansion_function_postprocessing.yaml"><img src="https://raw.githubusercontent.com/jwzhanggy/tinyBIG/main/docs/assets/img/yaml_icon.png" alt="Yaml Logo" style="height: 2em; vertical-align: middle; margin-right: 4px;"></a> <a href="https://github.com/jwzhanggy/tinyBIG/blob/main/docs/notes/expansion_tutorial.py"> <img src="https://raw.githubusercontent.com/jwzhanggy/tinyBIG/main/docs/assets/img/python_icon.svg" alt="Python Logo" style="height: 2em; vertical-align: middle; margin-right: 10px;"> </a>{% endset %}


|                     Tutorial ID                      |       Tutorial Title        | Released Date |         Related Files          |
|:----------------------------------------------------:|:---------------------------:|:-------------:|:------------------------------:|
|      [Tutorial 0](../../guides/quick_start.md)       |     Quickstart Tutorial     | July 4, 20204 | {{quickstart_tutorial_files}}  |
|     [Tutorial 1](./module/expansion_function.md)     |  Data Expansion Functions   | July 6, 20204 |  {{expansion_tutorial_files}}  |


[//]: # (| [Tutorial 2]&#40;./module/extended_nested_expansion.md&#41; | Extended and Nested Data Expansions |     TBD      | To Be Provided  |)

[//]: # (|  [Tutorial 3]&#40;./module/reconciliation_function.md&#41;  | Parameter Reconciliation Functions  |     TBD      | To Be Provided  |)

[//]: # (|    [Tutorial 4]&#40;./module/remainder_function.md&#41;     |         Remainder Functions         |     TBD      | To Be Provided  |)

[//]: # (| [Tutorial 5]&#40;./module/data_processing_function.md&#41;  |      Data Processing Functions      |     TBD      | To Be Provided  |)

[//]: # ()
[//]: # ()
[//]: # (## Tutorials on {{ our }} Model Architecture)

[//]: # ()
[//]: # (|             Tutorial ID             |              Tutorial Title              | Release Date |   Colab Link    |)

[//]: # (|:-----------------------------------:|:----------------------------------------:|:------------:|:---------------:|)

[//]: # (| [Tutorial 6]&#40;./model/rpn_model.md&#41;  |          RPN Model Architecture          |     TBD      | To Be Provided  |)

[//]: # (|  [Tutorial 7]&#40;./model/wide_rpn.md&#41;  |       RPN with Wide Architectures        |     TBD      | To Be Provided  |)

[//]: # (|  [Tutorial 8]&#40;./model/deep_rpn.md&#41;  |        RPN with Deep Architecture        |     TBD      | To Be Provided  |)

[//]: # (| [Tutorial 9]&#40;./model/rpn_config.md&#41; |         RPN Model Configurations         |     TBD      | To Be Provided  |)

[//]: # ()
[//]: # ()
[//]: # (## Tutorials on Datasets for {{ our }} Training)

[//]: # ()
[//]: # (|              Tutorial ID               |       Tutorial Title        | Release Date |   Colab Link    |)

[//]: # (|:--------------------------------------:|:---------------------------:|:------------:|:---------------:|)

[//]: # (| [Tutorial 10]&#40;./data/function_data.md&#41; | Continuous Function Dataset |     TBD      | To Be Provided  |)

[//]: # (|  [Tutorial 11]&#40;./data/image_data.md&#41;   |   Discrete Image Dataset    |     TBD      | To Be Provided  |)

[//]: # (|   [Tutorial 12]&#40;./data/text_data.md&#41;   |    Discrete Text Dataset    |     TBD      | To Be Provided  |)

[//]: # (| [Tutorial 13]&#40;./data/tabular_data.md&#41;  |   Classic Tabular Dataset   |     TBD      | To Be Provided  |)

[//]: # ()
[//]: # (## Tutorials on Deep Function Learning Tasks with {{ our }})

[//]: # ()
[//]: # (|                   Tutorial ID                   |           Tutorial Title           | Release Date |   Colab Link    |)

[//]: # (|:-----------------------------------------------:|:----------------------------------:|:------------:|:---------------:|)

[//]: # (| [Tutorial 14]&#40;./task/function_approximation.md&#41; | Continuous Function Approximation  |     TBD      | To Be Provided  |)

[//]: # (|  [Tutorial 15]&#40;./task/image_classification.md&#41;  |   Discrete Image Classification    |     TBD      | To Be Provided  |)

[//]: # (|  [Tutorial 16]&#40;./task/text_classification.md&#41;   |    Discrete Text Classification    |     TBD      | To Be Provided  |)

[//]: # (|  [Tutorial 17]&#40;./task/dependency_inference.md&#41;  | Probabilistic Dependency Inference |     TBD      | To Be Provided  |)

[//]: # ()
